@@ -127,7 +127,7 @@ class Campaign:
             self.osm = None
 
     def __call__(self, name):
-        results = list(filter(lambda file: file.name == name, self.files))
+        results = list(filter(lambda file: file.filename == name, self.files))
         if len(results) == 1:
             return results[0]
         else:
@@ -208,7 +208,7 @@ class Campaign:
             coords = gps_series.to_ipyleaflef()
 
             if coords == [[]]:
-                logger.warning("Coordinates are empty in file: %s" % f.name)
+                logger.warning("Coordinates are empty in file: %s" % f.filename)
             else:
                 file_polyline = Polyline(locations=coords, color=color, fill=False, weight=4,
                                          dash_array='10, 10')
@@ -237,11 +237,11 @@ class Campaign:
                 start_message = HTML()
                 end_message = HTML()
                 start_message.value = "<p>Start:</p><p>" \
-                                      + str(f.name or '') + "</p><p>" \
+                                      + str(f.filename or '') + "</p><p>" \
                                       + str(getattr(f.device, "manufacturer", "")) + "; " \
                                       + str(getattr(f.device, "model", "")) + "</p>"
                 end_message.value = "<p>End:</p><p>" \
-                                    + str(f.name or '') + "</p><p>" \
+                                    + str(f.filename or '') + "</p><p>" \
                                     + str(getattr(f.device, "manufacturer", "")) + "; " \
                                     + str(getattr(f.device, "model", "")) + "</p>"
 
@@ -317,11 +317,14 @@ class Campaign:
         """
         self.files = []
 
-    def create_map(self, center: Tuple[float, float] = None, show_railway_elements=False) -> Map:
+    def create_map(self, center: Tuple[float, float] = None,
+                   show_gps_tracks=True,
+                   show_railway_elements=False) -> Map:
         """ Creates a ipyleaflet map showing the GPS tracks of measurement files
 
         Parameters
         ----------
+        show_gps_tracks
         center
         show_railway_elements
 
@@ -346,7 +349,9 @@ class Campaign:
 
         # Plot GPS point for each measurement and OSM Tracks
         m = self.add_osm_routes_to_map(m)
-        m = self.add_tracks_to_map(m)
+
+        if show_gps_tracks:
+            m = self.add_tracks_to_map(m)
 
         if show_railway_elements:
             m = self.add_osm_railway_elements_to_map(m)
