@@ -91,11 +91,12 @@ class TimeSeries(ABC):
 
                 self._timedelta: np.ndarray = np.diff(self._time)
             else:
-                logger.info("(%s) Cannot cutoff series if timeseries is empty or series already starts at 0"
-                            % self.filename)
+                logger.info("(%s) Cannot cutoff %s if timeseries is empty or series already starts at 0"
+                            % (self.filename, self.__class__.__name__))
         else:
-            logger.warning("(%s) Cannot cutoff timeseries, series timestamp_when_started "
-                           "and/or timestamp_when_stopped are None" % self.filename)
+            logger.warning("(%s) Cannot cutoff %s, if timestamp_when_started " % (self.filename,
+                                                                                  self.__class__.__name__) +
+                           "and/or timestamp_when_stopped are None")
 
         pass
 
@@ -201,7 +202,8 @@ class TimeSeries(ABC):
         if not np.array_equal(self._time, np.array(None)) and len(self._time) > 0:
             if method == "timestamp":
                 if self._time[0] == 0:
-                    logger.info("(%s) Timeseries already starts at 0, cant sync with t0" % self.filename)
+                    logger.info("(%s) %s already starts at 0, cant sync with t0" % (self.filename,
+                                                                                    self.__class__.__name__))
                     self.time = self._time.astype(timedelta_unit)
                 else:
                     if sync_timestamp:
@@ -211,8 +213,8 @@ class TimeSeries(ABC):
                         self.time = (self._time - self._time[0]).astype(timedelta_unit)
             elif method == "seconds":
                 if self._time[0] == 0:
-                    logger.info("(%s) Timeseries already starts at 0, cant sync with t0, only converting to seconds"
-                                % self.filename)
+                    logger.info("(%s) %s already starts at 0, cant sync with t0, only converting to seconds"
+                                % (self.filename, self.__class__.__name__))
                     self.time = self._time.astype(timedelta_unit) / np.timedelta64(1, "s")
                 else:
                     if sync_timestamp:
@@ -222,15 +224,16 @@ class TimeSeries(ABC):
                         self.time = (self._time - self._time[0]).astype(timedelta_unit) / np.timedelta64(1, "s")
             elif method == "device_time":
                 if self._time[0] == 0:
-                    logger.info("(%s) Timeseries already starts at 0, timestamp syncing not appropriate"
-                                % self.filename)
+                    logger.info("(%s) %s already starts at 0, timestamp syncing not appropriate"
+                                % (self.filename, self.__class__.__name__))
+
                     self.time = self._time.astype(timedelta_unit) + sync_time
                 else:
                     self.time = (self._time - sync_timestamp).astype(timedelta_unit) + sync_time
             elif method == "gps_time" or method == "ntp_time":
                 if self._time[0] == 0:
-                    logger.info("(%s) Timeseries already starts at 0, cant sync to due to lack of proper timestamp"
-                                % self.filename)
+                    logger.info("(%s) %s already starts at 0, cant sync to due to lack of proper timestamp"
+                                % (self.filename, self.__class__.__name__))
                 else:
                     self.time = (self._time - sync_timestamp).astype(timedelta_unit) + sync_time
                 pass
